@@ -2,3 +2,10 @@ from .base_element import BaseElement
 from .alert_element import AlertElement
 from .page_element import PageElement
 from .locator import Locator
+
+__all__ = [
+    'alert_element',
+    'base_element',
+    'locator',
+    'page_element'
+]
